pigeon_copy method

  1. @override
CLPlacemark pigeon_copy()

Instantiates and returns a functionally identical object to oneself.

Outside of tests, this method should only ever be called by PigeonInstanceManager.

Subclasses should always override their parent's implementation of this method.

Implementation

@override
CLPlacemark pigeon_copy() {
  return CLPlacemark.pigeon_detached(
    pigeon_binaryMessenger: pigeon_binaryMessenger,
    pigeon_instanceManager: pigeon_instanceManager,
    location: location,
    name: name,
    thoroughfare: thoroughfare,
    subThoroughfare: subThoroughfare,
    locality: locality,
    subLocality: subLocality,
    administrativeArea: administrativeArea,
    subAdministrativeArea: subAdministrativeArea,
    postalCode: postalCode,
    isoCountryCode: isoCountryCode,
    country: country,
    postalAddress: postalAddress,
    observeValue: observeValue,
  );
}